@@ -1,8 +1,8 @@
 package App::FirefoxUtils;
 
-our $DATE = '2019-11-23'; # DATE
+our $DATE = '2019-11-28'; # DATE
 our $DIST = 'App-FirefoxUtils'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -38,7 +38,7 @@ sub _do_firefox {
             if ($args{users} && @{ $args{users} }) {
                 return 0 unless grep { $p->{uid} == $_ } @{ $args{users} };
             }
-            return 0 unless $p->{fname} =~ /\A(Web Content|firefox-bin)\z/;
+            return 0 unless $p->{fname} =~ /\A(Web Content|WebExtensions|firefox-bin)\z/;
             log_trace "Found PID %d (cmdline=%s, fname=%s, uid=%d)", $p->{pid}, $p->{cmndline}, $p->{fname}, $p->{uid};
             1;
         },
@@ -102,7 +102,7 @@ App::FirefoxUtils - Utilities related to Firefox
 
 =head1 VERSION
 
-This document describes version 0.001 of App::FirefoxUtils (from Perl distribution App-FirefoxUtils), released on 2019-11-23.
+This document describes version 0.002 of App::FirefoxUtils (from Perl distribution App-FirefoxUtils), released on 2019-11-28.
 
 =head1 SYNOPSIS
 
